@@ -86,6 +86,7 @@ namespace Uml
             Component,
             Deployment,
             EntityRelationship,
+            Object,
             N_DIAGRAMTYPES   // must remain last
         };
         QString toString(Enum item);
@@ -349,4 +350,6 @@ static inline QString toString(Uml::Visibility::Enum visibility)
     return Uml::Visibility::toString(visibility);
 }
 
+qreal toDoubleFromAnyLocale(const QString &s);
+
 #endif
