@@ -145,7 +145,7 @@ void ToolBarStateMessages::mouseReleaseWidget()
     //TODO When an association between UMLObjects of invalid types is made, an error message
     //is shown. Shouldn't also a message be used here?
     if (m_pMouseEvent->button() != Qt::LeftButton ||
-                currentWidget()->baseType() != WidgetBase::wt_Object) {
+                !currentWidget()->isObjectWidget()) {
         cleanMessage();
         return;
     }
@@ -313,7 +313,7 @@ void ToolBarStateMessages::setupMessageWidget(MessageWidget *message)
     //Shouldn't it cancel also the whole creation?
     ft->showOperationDialog();
     message->setTextPosition();
-    m_pUMLScene->widgetList().append(ft);
+    m_pUMLScene->addWidget(ft);
 
     UMLApp::app()->document()->setModified();
 }
