@@ -276,8 +276,8 @@ public:
 
     // Load/Save interface:
 
-    virtual void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
-    virtual bool loadFromXMI(QDomElement & qElement);
+    virtual void saveToXMI1(QDomDocument & qDoc, QDomElement & qElement);
+    virtual bool loadFromXMI1(QDomElement & qElement);
 
     bool loadUISDiagram(QDomElement & qElement);
     UMLWidget* loadWidgetFromXMI(QDomElement& widgetElement);
@@ -362,6 +362,15 @@ protected:
 
     virtual void drawBackground(QPainter *painter, const QRectF &rect);
 
+#if QT_VERSION >= 0x050000
+#if !(QT_DEPRECATED_SINCE(5, 0))
+    inline QGraphicsItem *itemAt(const QPointF &position) const {
+        QList<QGraphicsItem *> itemsAtPoint = items(position);
+        return itemsAtPoint.isEmpty() ? 0 : itemsAtPoint.first();
+    }
+#endif
+#endif
+
     int m_nCollaborationId;  ///< Used for creating unique name of collaboration messages.
     QPointF m_Pos;
     bool m_bCreateObject;
